@@ -1,5 +1,4 @@
-import sys
-from typing import Optional, Union
+from typing import Any, Dict, Optional, Union
 
 from pytablewriter.style import Cell, Style
 from tcolorpy import Color
@@ -19,11 +18,12 @@ def _calc_other_ground_color(color: Color) -> str:
     return "white"
 
 
-def col_separator_style_filter(lcell: Cell, rcell: Cell, **kwargs) -> Optional[Style]:
-    fg_color = None  # type: Union[Color, str, None]
-    bg_color = None  # type: Union[Color, str, None]
+def col_separator_style_filter(
+    lcell: Cell, rcell: Cell, **kwargs: Dict[str, Any]
+) -> Optional[Style]:
+    fg_color: Union[Color, str, None] = None
+    bg_color: Union[Color, str, None] = None
     row = lcell.row if lcell else rcell.row
-    col = lcell.col if lcell else rcell.col
 
     color = Color(kwargs.get("color", DEFAULT_COLOR))
 
@@ -39,9 +39,9 @@ def col_separator_style_filter(lcell: Cell, rcell: Cell, **kwargs) -> Optional[S
     return None
 
 
-def style_filter(cell: Cell, **kwargs) -> Optional[Style]:
-    fg_color = None  # type: Union[Color, str, None]
-    bg_color = None  # type: Union[Color, str, None]
+def style_filter(cell: Cell, **kwargs: Dict[str, Any]) -> Optional[Style]:
+    fg_color: Union[Color, str, None] = None
+    bg_color: Union[Color, str, None] = None
 
     color = Color(kwargs.get("color", DEFAULT_COLOR))
 
